@@ -80,6 +80,7 @@ class Model:
 
         :cl: scalar index number of class
         """
+        logger.debug('cl: ' + str(cl))
         fv = self.createFV(data, seeds, cl)
         self.train(fv, cl)
 
@@ -411,7 +412,6 @@ class ImageGraphCut:
         deb = True
         # import py3DSeedEditor as ped
 
-
         from PyQt4.QtCore import pyqtRemoveInputHook
         pyqtRemoveInputHook()
         import scipy
@@ -469,7 +469,7 @@ class ImageGraphCut:
         logger.debug('msinds ' + str(msinds.shape))
         if deb:
             import sed3
-            pd = sed3.sed3(msinds) # ), contour=seg)
+            pd = sed3.sed3(msinds)  # ), contour=seg)
             pd.show()
 
         # intensity values for indexes
@@ -563,11 +563,41 @@ class ImageGraphCut:
 
         return: [0, 1, 1, 0, 2, 0]
 
+        If the data are not consistent, it will take the maximal value
+
         """
         # get unique labels and their first indexes
-        lab, linds = np.unique(inds, return_index=True)
+        # lab, linds = np.unique(inds, return_index=True)
 # compute values by indexes
-        values = data.reshape(-1)[linds]
+        # values = data.reshape(-1)[linds]
+
+# alternative slow implementation
+# if there are different data on same index, it will take
+# maximal value
+        # lab = np.unique(inds)
+        # values = [0]*len(lab)
+        # for label in lab:
+        #     values[label] = np.max(data[inds == label])
+        #
+        # values = np.asarray(values)
+
+# yet another implementation
+        values = [None] * (np.max(inds) + 1)
+
+        linear_inds = inds.ravel()
+        linear_data = data.ravel()
+        for i in range(0, len(linear_inds)):
+            # going over all data pixels
+
+            if values[linear_inds[i]] is None:
+                # this index is found for first
+                values[linear_inds[i]] = linear_data[i]
+            elif values[linear_inds[i]] < linear_data[i]:
+                # here can be changed maximal or minimal value
+                values[linear_inds[i]] = linear_data[i]
+
+        values = np.asarray(values)
+
         return values
 
     def __relabel(self, data):
@@ -981,6 +1011,7 @@ class ImageGraphCut:
 
         return result_labeling
 
+
 def getPriorityObjects(data, nObj=1, seeds=None, debug=False):
     """
 
